@@ -1,5 +1,5 @@
 package Language::LispPerl::Evaler;
-$Language::LispPerl::Evaler::VERSION = '0.006';
+$Language::LispPerl::Evaler::VERSION = '0.007';
 use Moose;
 
 use File::ShareDir;
@@ -90,7 +90,7 @@ sub clear_exception{
 
 sub push_scope {
     my $self    = shift;
-    my $context = shift // confess("Cannot push undef context");
+    my $context = shift() || confess("Cannot push untrue context");
     my %c       = %{$context};
     my @ns      = @{ $c{$namespace_key} };
     $c{$namespace_key} = \@ns;
@@ -530,7 +530,7 @@ sub _eval {
             # Fallback to current scope if the function
             # definition didnt shallow copy its current scope at the time of definition.
             # This is the case when the evaler is persisted and then defrosted.
-            my $scope  = $f->context() // $self->copy_current_scope();
+            my $scope  = defined( $f->context() ) ? $f->context() : $self->copy_current_scope();
 
             my $fn     = $fvalue;
             my $fargs  = $fn->second();
@@ -590,7 +590,7 @@ sub _eval {
             return $self->perlfunc_call( $perl_func, $meta, \@args, $ast );
         }
         elsif ( $ftype eq "macro" ) {
-            my $scope  = $f->context() // $self->copy_current_scope();
+            my $scope  = defined( $f->context() ) ? $f->context() : $self->copy_current_scope();
             my $fn    = $fvalue;
             my $fargs = $fn->third();
             my @rargs = $ast->slice( 1 .. $ast->size() - 1 );
